@@ -1,6 +1,6 @@
  /* ================================================================== *
   * FILE: tclreadline.c
-  * $Id: 485f0a072fdb95b999c3e61c514ab2fadd7c8a42 $
+  * $Id: e1d64b5f9164e56a9d05a4c13ac76f87646dfa4d $
   * ---
   * tclreadline -- gnu readline for tcl
   * http://www.zellner.org/tclreadline/
@@ -47,7 +47,7 @@ static const char* tclrl_version_str = TCLRL_VERSION_STR;
 static const char* tclrl_patchlevel_str = TCLRL_PATCHLEVEL_STR;
 
 #define MALLOC(size) malloc(size)
-#define FREE(ptr) free(ptr); ptr = NULL
+#define FREE(ptr) (free(ptr), ptr = NULL)
 
 enum {
     _CMD_SET = (1 << 0),
